@@ -44,15 +44,6 @@ class Valve(Block):
             self.add_connection(new_input_conn, is_input=True)
             self.add_connection(new_output_conn, is_input=False)
 
-    def export_xml_other_parameters(self) -> ETree.Element:
-
-        other_tree = ETree.Element("Other")
-        return other_tree
-
-    def append_xml_other_parameters(self, input_list: ETree.Element):
-
-        pass
-
     def export_xml_connection_list(self) -> ETree.Element:
 
         xml_connection_list = ETree.Element("Connections")
